# Algebraeon

This is a Python wrapper around [the Rust library of the same name](https://github.com/pishleback/Algebraeon). It currently supports only a _very_ small subset of the capabilities of the Rust library.

There is [![Discord](https://img.shields.io/badge/Discord-Join%20Chat-7289DA?logo=discord&logoColor=white)](https://discord.gg/DBqbPqPMKR) for informal discussions about Algebraeon.

See the [User Guide](https://pishleback.github.io/Algebraeon-Python/) to get started using Algebraeon.